@@ -160,7 +160,9 @@
 #include "token_info-5.21.1.h"
 #elif PERL_VERSION == 21 && PERL_SUBVERSION == 4
 #include "token_info-5.21.4.h"
-#elif PERL_VERSION > 21 || (PERL_VERSION == 21 && PERL_SUBVERSION > 4)
+#elif PERL_VERSION == 21 && PERL_SUBVERSION == 5
+#include "token_info-5.21.5.h"
+#elif PERL_VERSION > 21 || (PERL_VERSION == 21 && PERL_SUBVERSION > 5)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
